@@ -14,14 +14,10 @@ mod oberon_0_parser;
 use crate::errors::*;
 use crate::oberon_0_grammar::Oberon0Grammar;
 use crate::oberon_0_parser::parse;
-use id_tree::Tree;
-use id_tree_layout::Layouter;
 use log::debug;
-use parol_runtime::parser::ParseTreeType;
+use parol::generate_tree_layout;
 use std::env;
 use std::fs;
-use std::path::PathBuf;
-use std::str::FromStr;
 
 // To rebuild the parser sources from scratch use the command build_parsers.ps1
 
@@ -45,26 +41,8 @@ fn run() -> Result<()> {
             .chain_err(|| format!("Failed parsing file {}", file_name))?;
         println!("\n{} successfully parsed!", file_name);
         println!("{}", oberon_0_grammar);
-        generate_tree_layout(&syntax_tree, &file_name)
+        generate_tree_layout(&syntax_tree, &file_name).chain_err(|| "Error generating tree layout")
     } else {
         Err("Please provide a file name as single parameter!".into())
     }
 }
-
-fn generate_tree_layout(syntax_tree: &Tree<ParseTreeType>, input_file_name: &str) -> Result<()> {
-    let mut svg_full_file_name = PathBuf::from_str(input_file_name).unwrap();
-    svg_full_file_name.set_extension("");
-    let file_name = svg_full_file_name
-        .file_name()
-        .unwrap()
-        .to_str()
-        .unwrap()
-        .to_owned();
-    svg_full_file_name.set_file_name(file_name);
-    svg_full_file_name.set_extension("svg");
-
-    Layouter::new(syntax_tree)
-        .with_file_path(std::path::Path::new(&svg_full_file_name))
-        .write()
-        .chain_err(|| "Failed writing layout")
-}
