@@ -4,7 +4,7 @@ extern crate error_chain;
 use parol::analysis::k_decision::{calculate_k_tuples, FirstCache, FollowCache};
 use parol::errors::*;
 use parol::generators::generate_terminal_names;
-use parol::obtain_cfg_ext;
+use parol::obtain_grammar_config;
 use parol::MAX_K;
 use std::env;
 
@@ -15,7 +15,7 @@ fn run() -> Result<()> {
     if args.len() > 1 {
         let file_name = args[1].clone();
 
-        let grammar_config = obtain_cfg_ext(&file_name, true)?;
+        let grammar_config = obtain_grammar_config(&file_name, true)?;
 
         let max_k = if args.len() > 2 {
             args[2]
