@@ -2,7 +2,7 @@
 extern crate error_chain;
 
 use parol::errors::*;
-use parol::{detect_left_recursions, obtain_cfg_ext};
+use parol::{detect_left_recursions, obtain_grammar_config};
 use std::env;
 
 quick_main!(run);
@@ -11,7 +11,7 @@ fn run() -> Result<()> {
     let args: Vec<String> = env::args().collect();
     if args.len() > 1 {
         let file_name = args[1].clone();
-        let grammar_config = obtain_cfg_ext(&file_name, false)?;
+        let grammar_config = obtain_grammar_config(&file_name, false)?;
         let recursions = detect_left_recursions(&grammar_config.cfg);
         if recursions.is_empty() {
             println!("No left recursions found!\n");
